/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Organizational *
* Sentencing Guidelines: Thirty Years of Innovation and Influence report file and create *
* a SAS dataset.                                                                         *   
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Org_Report_Public_2022.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Org_Report_Public_2022 ;

DATA library.&dataset ;
INFILE datafile LRECL=270;
INPUT
   FISCALYR  1-8            BUSINESS  9-16           INCORLOC  17-24       
   EMPLOYNM  25-32          OWNSTRCT  33-40          OWNERSHIP  41-48      
   PRIMOFF_R  49-56         NEWCNVTN  57-61          FINEDUM  62-69        
   RESTDUM  70-77           FINERESTDUM  78-85       FORFEITR  86-94       
   FORDUM  95-102           PROBATN  103-110         PROBDUM  111-118      
   CANTPAY_R  119-126       FINSTDS  127-134         CH8DUM  135-142       
   ORDERCE  143-150         COMPLYPR  151-158        INDIVID_PRES  159-166 
   COMPLY_R  167-174        TOLERNCE  175-182        TOLERDUM  183-190     
   VIOLATE  191-198         VIOLDUM  199-206         CRIMPURP  207-214     
   HSMISCND  215-222        HISTORY  223-230         HISTDUM  231-238      
   OBSTRUCT  239-246        OBSTRDUM  247-254        ACCEPT  255-262       
   ACCEPDUM  263-270      ;                       

LABEL
   INCORLOC = "INCORLOC"
   ORDERCE = "ORDERCE"
;

LENGTH
   FISCALYR 4               BUSINESS 3               INCORLOC 3            
   EMPLOYNM 3               OWNSTRCT 3               OWNERSHIP 3           
   PRIMOFF_R 3              NEWCNVTN 3               FINEDUM 3             
   RESTDUM 3                FINERESTDUM 3            FORFEITR 6            
   FORDUM 3                 PROBATN 3                PROBDUM 3             
   CANTPAY_R 3              FINSTDS 3                CH8DUM 3              
   ORDERCE 3                COMPLYPR 3               INDIVID_PRES 3        
   COMPLY_R 3               TOLERNCE 3               TOLERDUM 3            
   VIOLATE 3                VIOLDUM 3                CRIMPURP 3            
   HSMISCND 3               HISTORY 3                HISTDUM 3             
   OBSTRUCT 3               OBSTRDUM 3               ACCEPT 3              
   ACCEPDUM 3 ;

        

RUN ;
